@@ -1,24 +1,22 @@
 import os
 from datetime import datetime, timedelta
+from typing import Any, List
 
 from airflow.models.dag import DAG
 from airflow.providers.amazon.aws.operators.s3 import (
     S3CreateBucketOperator,
+    S3CreateObjectOperator,
     S3DeleteBucketOperator,
 )
-from airflow.providers.amazon.aws.transfers.local_to_s3 import (
-    LocalFilesystemToS3Operator,
-)
 
 from astronomer.providers.amazon.aws.sensors.s3 import (
     S3KeySensorAsync,
-    S3KeySizeSensorAsync,
     S3KeysUnchangedSensorAsync,
-    S3PrefixSensorAsync,
 )
 
 S3_BUCKET_NAME = os.getenv("S3_BUCKET_NAME", "test-bucket-astronomer-providers")
-S3_BUCKET_KEY = os.getenv("S3_BUCKET_KEY", "test/example_s3_test_file.txt")
+S3_BUCKET_KEY = os.getenv("S3_BUCKET_KEY", "test")
+S3_BUCKET_KEY_LIST = os.getenv("S3_BUCKET_KEY_LIST", "test2")
 S3_BUCKET_WILDCARD_KEY = os.getenv("S3_BUCKET_WILDCARD_KEY", "test*")
 PREFIX = os.getenv("S3_PREFIX", "test")
 INACTIVITY_PERIOD = float(os.getenv("INACTIVITY_PERIOD", 5))
@@ -26,6 +24,14 @@ AWS_DEFAULT_REGION = os.getenv("AWS_DEFAULT_REGION", "us-east-2")
 LOCAL_FILE_PATH = os.getenv("LOCAL_FILE_PATH", "/usr/local/airflow/dags/example_s3_test_file.txt")
 AWS_CONN_ID = os.getenv("ASTRO_AWS_S3_CONN_ID", "aws_s3_default")
 EXECUTION_TIMEOUT = int(os.getenv("EXECUTION_TIMEOUT", 6))
+DATA = os.environ.get(
+    "DATA",
+    """
+apple,0.5
+milk,2.5
+bread,4.0
+""",
+)
 
 default_args = {
     "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
@@ -41,6 +47,18 @@ with DAG(
     default_args=default_args,
     tags=["example", "async", "s3"],
 ) as dag:
+    # [START howto_sensor_s3_key_function_definition]
+    def check_fn(files: List[Any]) -> bool:
+        """
+        Example of custom check: check if all files are bigger than ``1kB``
+
+        :param files: List of S3 object attributes.
+        :return: true if the criteria is met
+        :rtype: bool
+        """
+        return all(f.get("Size", 0) > 1024 for f in files)
+
+    # [END howto_sensor_s3_key_function_definition]
     create_bucket = S3CreateBucketOperator(
         task_id="create_bucket",
         region_name=AWS_DEFAULT_REGION,
@@ -48,50 +66,52 @@ with DAG(
         aws_conn_id=AWS_CONN_ID,
     )
 
-    create_local_to_s3_job = LocalFilesystemToS3Operator(
-        task_id="create_local_to_s3_job",
-        filename=LOCAL_FILE_PATH,
-        dest_key=S3_BUCKET_KEY,
-        dest_bucket=S3_BUCKET_NAME,
+    create_object = S3CreateObjectOperator(
+        task_id="s3_create_object",
+        s3_bucket=S3_BUCKET_NAME,
+        s3_key=S3_BUCKET_KEY,
+        data=DATA,
         replace=True,
-        aws_conn_id=AWS_CONN_ID,
     )
 
-    # [START howto_sensor_s3_key_async]
-    waiting_for_s3_key = S3KeySensorAsync(
-        task_id="waiting_for_s3_key",
+    # [START howto_sensor_async_s3_key_single_key]
+    # Check if a file exists
+    sensor_one_key = S3KeySensorAsync(
+        task_id="s3_sensor_one_key",
+        bucket_name=S3_BUCKET_NAME,
         bucket_key=S3_BUCKET_KEY,
-        wildcard_match=False,
-        bucket_name=S3_BUCKET_NAME,
         aws_conn_id=AWS_CONN_ID,
     )
-    # [END howto_sensor_s3_key_async]
+    # [END howto_sensor_async_s3_key_single_key]
 
-    check_if_wildcard_exists = S3KeySensorAsync(
-        task_id="check_if_wildcard_exists",
-        bucket_key=S3_BUCKET_WILDCARD_KEY,
-        wildcard_match=True,
-        bucket_name=S3_BUCKET_NAME,
-        aws_conn_id=AWS_CONN_ID,
+    create_object_for_key2 = S3CreateObjectOperator(
+        task_id="s3_create_object_for_key2",
+        s3_bucket=S3_BUCKET_NAME,
+        s3_key=S3_BUCKET_KEY_LIST,
+        data=DATA,
+        replace=True,
     )
 
-    # [START howto_sensor_s3_key_size_async]
-    check_if_key_with_size_without_wildcard = S3KeySizeSensorAsync(
-        task_id="check_if_key_with_size_without_wildcard",
+    # [START howto_sensor_async_s3_key_multiple_keys]
+    # Check if both files exist
+    sensor_two_keys = S3KeySensorAsync(
+        task_id="s3_sensor_two_keys",
+        bucket_name=S3_BUCKET_NAME,
+        bucket_key=[S3_BUCKET_KEY, S3_BUCKET_KEY_LIST],
+        aws_conn_id=AWS_CONN_ID,
+    )
+    # [END howto_sensor_async_s3_key_multiple_keys]
+
+    # [START howto_sensor_async_s3_key_function]
+    # Check if a file exists and match a certain pattern defined in check_fn
+    sensor_key_with_function = S3KeySensorAsync(
+        task_id="s3_sensor_key_function",
+        bucket_name=S3_BUCKET_NAME,
         bucket_key=S3_BUCKET_KEY,
-        wildcard_match=False,
-        bucket_name=S3_BUCKET_NAME,
-        aws_conn_id=AWS_CONN_ID,
-    )
-    # [END howto_sensor_s3_key_size_async]
-
-    check_if_key_with_size_with_wildcard = S3KeySizeSensorAsync(
-        task_id="check_if_key_with_size_with_wildcard",
-        bucket_key=S3_BUCKET_WILDCARD_KEY,
-        wildcard_match=True,
-        bucket_name=S3_BUCKET_NAME,
+        check_fn=check_fn,
         aws_conn_id=AWS_CONN_ID,
     )
+    # [END howto_sensor_async_s3_key_function]
 
     # [START howto_sensor_s3_key_unchanged_async]
     check_s3_key_unchanged_sensor = S3KeysUnchangedSensorAsync(
@@ -106,17 +126,9 @@ with DAG(
     )
     # [END howto_sensor_s3_key_unchanged_async]
 
-    # [START howto_sensor_s3_key_prefix_async]
-    check_s3_prefix_sensor = S3PrefixSensorAsync(
-        task_id="check_s3_prefix_sensor",
-        bucket_name=S3_BUCKET_NAME,
-        prefix=PREFIX,
-        aws_conn_id=AWS_CONN_ID,
-    )
-    # [END howto_sensor_s3_key_prefix_async]
-
     delete_bucket = S3DeleteBucketOperator(
         task_id="delete_bucket",
+        trigger_rule="all_done",
         force_delete=True,
         bucket_name=S3_BUCKET_NAME,
         aws_conn_id=AWS_CONN_ID,
@@ -124,12 +136,8 @@ with DAG(
 
 (
     create_bucket
-    >> create_local_to_s3_job
-    >> waiting_for_s3_key
-    >> check_if_wildcard_exists
-    >> check_if_key_with_size_without_wildcard
-    >> check_if_key_with_size_with_wildcard
+    >> create_object
+    >> [sensor_one_key, create_object_for_key2, sensor_two_keys, sensor_key_with_function]
     >> check_s3_key_unchanged_sensor
-    >> check_s3_prefix_sensor
     >> delete_bucket
 )
