@@ -1,33 +1,42 @@
-from datetime import datetime
-from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Union, cast
-from urllib.parse import urlparse
+import typing
+import warnings
+from datetime import timedelta
+from typing import Any, Callable, List, Optional, Sequence, Union, cast
 
 from airflow.exceptions import AirflowException
-from airflow.models.baseoperator import BaseOperator
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
-from airflow.utils.context import Context
+from airflow.providers.amazon.aws.sensors.s3 import S3KeysUnchangedSensor
+from airflow.sensors.base import BaseSensorOperator
 
 from astronomer.providers.amazon.aws.triggers.s3 import (
-    S3KeySizeTrigger,
     S3KeysUnchangedTrigger,
     S3KeyTrigger,
-    S3PrefixTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
-class S3KeySensorAsync(BaseOperator):
+class S3KeySensorAsync(BaseSensorOperator):
     """
-    Waits for a key (a file-like instance on S3) to be present in a S3 bucket
-    asynchronously. S3 being a key/value it does not support folders. The path
-    is just a key a resource.
+    Waits for one or multiple keys (a file-like instance on S3) to be present in a S3 bucket.
+    S3 being a key/value it does not support folders. The path is just a key
+    a resource.
 
-    :param bucket_key: The key being waited on. Supports full s3:// style url
+    :param bucket_key: The key(s) being waited on. Supports full s3:// style url
         or relative path from root level. When it's specified as a full s3://
-        url, please leave bucket_name as `None`.
+        url, please leave bucket_name as `None`
     :param bucket_name: Name of the S3 bucket. Only needed when ``bucket_key``
-        is not provided as a full s3:// url.
+        is not provided as a full s3:// url. When specified, all the keys passed to ``bucket_key``
+        refers to this bucket
     :param wildcard_match: whether the bucket_key should be interpreted as a
         Unix wildcard pattern
+    :param check_fn: Function that receives the list of the S3 objects,
+        and returns a boolean:
+        - ``True``: the criteria is met
+        - ``False``: the criteria isn't met
+        **Example**: Wait for any S3 object size more than 1 megabyte  ::
+
+            def check_fn(files: List) -> bool:
+                return any(f.get('Size', 0) > 1048576 for f in files)
     :param aws_conn_id: a reference to the s3 connection
     :param verify: Whether or not to verify SSL certificates for S3 connection.
         By default SSL certificates are verified.
@@ -39,6 +48,10 @@ class S3KeySensorAsync(BaseOperator):
         - ``path/to/cert/bundle.pem``: A filename of the CA cert bundle to uses.
                  You can specify this argument if you want to use a different
                  CA cert bundle than the one used by botocore.
+
+    .. seealso::
+        `For more information on how to use this sensor, take a look at the guide:
+        :ref:`howto/sensor:S3KeySensor`.
     """
 
     template_fields: Sequence[str] = ("bucket_key", "bucket_name")
@@ -46,46 +59,40 @@ class S3KeySensorAsync(BaseOperator):
     def __init__(
         self,
         *,
-        bucket_key: str,
+        bucket_key: Union[str, List[str]],
         bucket_name: Optional[str] = None,
         wildcard_match: bool = False,
+        check_fn: Optional[Callable[..., bool]] = None,
         aws_conn_id: str = "aws_default",
         verify: Optional[Union[str, bool]] = None,
         **kwargs: Any,
     ):
         super().__init__(**kwargs)
         self.bucket_name = bucket_name
-        self.bucket_key = bucket_key
+        self.bucket_key = [bucket_key] if isinstance(bucket_key, str) else bucket_key
         self.wildcard_match = wildcard_match
+        self.check_fn = check_fn
         self.aws_conn_id = aws_conn_id
         self.verify = verify
         self.hook: Optional[S3Hook] = None
 
-    def _resolve_bucket_and_key(self) -> None:
-        """If key is URI, parse bucket"""
-        if self.bucket_name is None:
-            self.bucket_name, self.bucket_key = S3Hook.parse_s3_url(self.bucket_key)
-        else:
-            parsed_url = urlparse(self.bucket_key)
-            if parsed_url.scheme != "" or parsed_url.netloc != "":
-                raise AirflowException("If bucket_name provided, bucket_key must be relative path, not URI.")
-
     def execute(self, context: Context) -> None:
-        """Check for a key in s3 and defers using the trigger"""
-        self._resolve_bucket_and_key()
+        """Check for a keys in s3 and defers using the trigger"""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=S3KeyTrigger(
                 bucket_name=cast(str, self.bucket_name),
                 bucket_key=self.bucket_key,
                 wildcard_match=self.wildcard_match,
+                check_fn=self.check_fn,
                 aws_conn_id=self.aws_conn_id,
                 verify=self.verify,
+                poke_interval=self.poke_interval,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Any = None) -> None:
+    def execute_complete(self, context: Context, event: Any = None) -> Optional[bool]:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -93,42 +100,17 @@ class S3KeySensorAsync(BaseOperator):
         """
         if event["status"] == "error":
             raise AirflowException(event["message"])
+        elif event["status"] == "success" and "s3_objects" in event:
+            files = typing.cast(List[str], event["s3_objects"])
+            if self.check_fn:
+                return self.check_fn(files)
         return None
 
 
 class S3KeySizeSensorAsync(S3KeySensorAsync):
     """
-    Waits for a key (a file-like instance on S3) to be present and be more than
-    some size in a S3 bucket asynchronously.
-    S3 being a key/value it does not support folders. The path is just a key
-    a resource.
-
-    :param bucket_key: The key being waited on. Supports full s3:// style url
-        or relative path from root level. When it's specified as a full s3://
-        url, please leave bucket_name as `None`.
-    :param bucket_name: Name of the S3 bucket. Only needed when ``bucket_key``
-        is not provided as a full s3:// url.
-    :param wildcard_match: whether the bucket_key should be interpreted as a
-        Unix wildcard pattern
-    :param aws_conn_id: a reference to the s3 connection
-    :param verify: Whether or not to verify SSL certificates for S3 connection.
-        By default SSL certificates are verified.
-        You can provide the following values:
-
-        - ``False``: do not validate SSL certificates. SSL will still be used
-                 (unless use_ssl is False), but SSL certificates will not be
-                 verified.
-        - ``path/to/cert/bundle.pem``: A filename of the CA cert bundle to uses.
-                 You can specify this argument if you want to use a different
-                 CA cert bundle than the one used by botocore.
-    :param check_fn: Function that receives the list of the S3 objects,
-        and returns the boolean:
-        - ``True``: a certain criteria is met
-        - ``False``: the criteria isn't met
-        **Example**: Wait for any S3 object size more than 1 megabyte  ::
-
-            def check_fn(self, data: List) -> bool:
-                return any(f.get('Size', 0) > 1048576 for f in data if isinstance(f, dict))
+    This class is deprecated.
+    Please use :class: `~astronomer.providers.amazon.aws.sensor.s3.S3KeySensorAsync`.
     """
 
     def __init__(
@@ -137,37 +119,19 @@ class S3KeySizeSensorAsync(S3KeySensorAsync):
         check_fn: Optional[Callable[..., bool]] = None,
         **kwargs: Any,
     ):
+        warnings.warn(
+            """
+            S3KeySizeSensorAsync is deprecated.
+            Please use `astronomer.providers.amazon.aws.sensor.s3.S3KeySensorAsync`.
+            """,
+            DeprecationWarning,
+            stacklevel=2,
+        )
         super().__init__(**kwargs)
         self.check_fn_user = check_fn
 
-    def execute(self, context: Context) -> None:
-        """Defers using the trigger, and check for the file size"""
-        self._resolve_bucket_and_key()
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=S3KeySizeTrigger(
-                bucket_name=cast(str, self.bucket_name),
-                bucket_key=self.bucket_key,
-                wildcard_match=self.wildcard_match,
-                aws_conn_id=self.aws_conn_id,
-                verify=self.verify,
-                check_fn_user=self.check_fn_user,
-            ),
-            method_name="execute_complete",
-        )
 
-    def execute_complete(self, context: Dict[str, Any], event: Any = None) -> None:
-        """
-        Callback for when the trigger fires - returns immediately.
-        Relies on trigger to throw an exception, otherwise it assumes execution was
-        successful.
-        """
-        if event["status"] == "error":
-            raise AirflowException(event["message"])
-        return None
-
-
-class S3KeysUnchangedSensorAsync(BaseOperator):
+class S3KeysUnchangedSensorAsync(S3KeysUnchangedSensor):
     """
     Checks for changes in the number of objects at prefix in AWS S3
     bucket and returns True if the inactivity period has passed with no
@@ -200,39 +164,16 @@ class S3KeysUnchangedSensorAsync(BaseOperator):
         when this happens. If false an error will be raised.
     """
 
-    template_fields: Sequence[str] = ("bucket_name", "prefix")
-
     def __init__(
         self,
-        *,
-        bucket_name: str,
-        prefix: str,
-        aws_conn_id: str = "aws_default",
-        verify: Optional[Union[bool, str]] = None,
-        inactivity_period: float = 60 * 60,
-        min_objects: int = 1,
-        previous_objects: Optional[Set[str]] = None,
-        allow_delete: bool = True,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
-        self.bucket_name = bucket_name
-        self.prefix = prefix
-        if inactivity_period < 0:
-            raise ValueError("inactivity_period must be non-negative")
-        self.inactivity_period = inactivity_period
-        self.min_objects = min_objects
-        self.previous_objects = previous_objects or set()
-        self.inactivity_seconds = 0
-        self.allow_delete = allow_delete
-        self.aws_conn_id = aws_conn_id
-        self.verify = verify
-        self.last_activity_time: Optional[datetime] = None
 
     def execute(self, context: Context) -> None:
         """Defers Trigger class to check for changes in the number of objects at prefix in AWS S3"""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=S3KeysUnchangedTrigger(
                 bucket_name=self.bucket_name,
                 prefix=self.prefix,
@@ -248,7 +189,7 @@ class S3KeysUnchangedSensorAsync(BaseOperator):
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Any = None) -> None:
+    def execute_complete(self, context: Context, event: Any = None) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -259,37 +200,12 @@ class S3KeysUnchangedSensorAsync(BaseOperator):
         return None
 
 
-class S3PrefixSensorAsync(BaseOperator):
+class S3PrefixSensorAsync(BaseSensorOperator):
     """
-    Async implementation of the S3 Prefix Sensor.
-    Gets deferred onto the Trigggerer and pokes
-    for a prefix or all prefixes to exist.
-    A prefix is the first part of a key,thus enabling
-    checking of constructs similar to glob ``airfl*`` or
-    SQL LIKE ``'airfl%'``. There is the possibility to precise a delimiter to
-    indicate the hierarchy or keys, meaning that the match will stop at that
-    delimiter. Current code accepts sane delimiters, i.e. characters that
-    are NOT special characters in the Python regex engine.
-
-    :param bucket_name: Name of the S3 bucket
-    :param prefix: The prefix being waited on. Relative path from bucket root level.
-    :param delimiter: The delimiter intended to show hierarchy.
-        Defaults to '/'.
-    :param aws_conn_id: a reference to the s3 connection
-    :param verify: Whether to verify SSL certificates for S3 connection.
-        By default, SSL certificates are verified.
-        You can provide the following values:
-
-        - ``False``: do not validate SSL certificates. SSL will still be used
-                 (unless use_ssl is False), but SSL certificates will not be
-                 verified.
-        - ``path/to/cert/bundle.pem``: A filename of the CA cert bundle to uses.
-                 You can specify this argument if you want to use a different
-                 CA cert bundle than the one used by botocore.
+    This class is deprecated.
+    Please use :class: `~astronomer.providers.amazon.aws.sensor.s3.S3KeySensorAsync`.
     """
 
-    template_fields: Sequence[str] = ("prefix", "bucket_name")
-
     def __init__(
         self,
         *,
@@ -300,35 +216,17 @@ class S3PrefixSensorAsync(BaseOperator):
         verify: Optional[Union[str, bool]] = None,
         **kwargs: Any,
     ):
+        warnings.warn(
+            """
+            S3PrefixSensor is deprecated.
+            Please use `astronomer.providers.amazon.aws.sensor.s3.S3KeySensorAsync`.
+            """,
+            DeprecationWarning,
+            stacklevel=2,
+        )
         super().__init__(**kwargs)
         self.bucket_name = bucket_name
         self.prefix = [prefix] if isinstance(prefix, str) else prefix
         self.delimiter = delimiter
         self.aws_conn_id = aws_conn_id
         self.verify = verify
-
-    def execute(self, context: Context) -> None:
-        """Defers trigger class to poke for a prefix or all prefixes to exist"""
-        self.log.info("Poking for prefix : %s in bucket s3://%s", self.prefix, self.bucket_name)
-        self.defer(
-            timeout=self.execution_timeout,
-            trigger=S3PrefixTrigger(
-                bucket_name=self.bucket_name,
-                prefix=self.prefix,
-                delimiter=self.delimiter,
-                aws_conn_id=self.aws_conn_id,
-                verify=self.verify,
-            ),
-            method_name="execute_complete",
-        )
-
-    def execute_complete(self, context: Dict[Any, Any], event: Dict[str, str]) -> None:
-        """
-        Callback for when the trigger fires - returns immediately.
-        Relies on trigger to throw an exception, otherwise it assumes execution was
-        successful.
-        """
-        if event["status"] == "error":
-            raise AirflowException(event["message"])
-        self.log.info(event["message"])
-        return None
