@@ -1,12 +1,13 @@
-from typing import Any, Dict, Optional
+from datetime import timedelta
+from typing import Dict, Optional
 
 from airflow.exceptions import AirflowException
 from airflow.providers.apache.hive.sensors.hive_partition import HivePartitionSensor
-from airflow.utils.context import Context
 
 from astronomer.providers.apache.hive.triggers.hive_partition import (
     HivePartitionTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
 class HivePartitionSensorAsync(HivePartitionSensor):
@@ -42,7 +43,7 @@ class HivePartitionSensorAsync(HivePartitionSensor):
     def execute(self, context: Context) -> None:
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=HivePartitionTrigger(
                 table=self.table,
                 schema=self.schema,
@@ -53,7 +54,7 @@ class HivePartitionSensorAsync(HivePartitionSensor):
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, str]] = None) -> str:
+    def execute_complete(self, context: Context, event: Optional[Dict[str, str]] = None) -> str:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
