@@ -60,7 +60,7 @@ class LivyTrigger(BaseTrigger):
             },
         )
 
-    async def run(self) -> AsyncIterator["TriggerEvent"]:  # type: ignore[override]
+    async def run(self) -> AsyncIterator["TriggerEvent"]:
         """
         Checks if the _polling_interval > 0, in that case it pools Livy for
         batch termination asynchrnonously.
