@@ -3,81 +3,30 @@ from typing import Any, Dict, List, Optional, Union, cast
 from aiohttp import ClientSession as ClientSession
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 from gcloud.aio.bigquery import Job, Table
 from google.cloud.bigquery import CopyJob, ExtractJob, LoadJob, QueryJob
 from requests import Session
 
 from astronomer.providers.google.common.hooks.base_google import GoogleBaseHookAsync
 
+try:
+    from airflow.providers.google.cloud.utils.bigquery import bq_cast
+except ImportError:
+    # For apache-airflow-providers-google < 8.5.0
+    from airflow.providers.google.cloud.hooks.bigquery import (  # type: ignore[no-redef,attr-defined] # noqa: E501 # pragma: no cover
+        _bq_cast as bq_cast,
+    )
+
 BigQueryJob = Union[CopyJob, QueryJob, LoadJob, ExtractJob]
 
 
-class _BigQueryHook(BigQueryHook):
-    @GoogleBaseHook.fallback_to_default_project_id
-    def insert_job(
-        self,
-        configuration: Dict[str, Any],
-        job_id: Optional[str] = None,
-        project_id: Optional[str] = None,
-        location: Optional[str] = None,
-        nowait: bool = False,
-    ) -> BigQueryJob:
-        """
-        Executes a BigQuery job. Initiates the job and returns job id.
-
-        See here: https://cloud.google.com/bigquery/docs/reference/v2/jobs
-
-        :param configuration: The configuration parameter maps directly to
-            BigQuery's configuration field in the job object. See
-            https://cloud.google.com/bigquery/docs/reference/v2/jobs for
-            details.
-        :param job_id: The ID of the job. The ID must contain only letters (a-z, A-Z),
-            numbers (0-9), underscores (_), or dashes (-). The maximum length is 1,024
-            characters. If not provided then uuid will be generated.
-        :param project_id: Google Cloud Project where the job is running
-        :param location: location the job is running
-        :param nowait: specify whether to insert job without waiting for the result
-        """
-        location = location or self.location
-        job_id = job_id or self._custom_job_id(configuration)
-
-        client = self.get_client(project_id=project_id, location=location)
-        job_data = {
-            "configuration": configuration,
-            "jobReference": {"jobId": job_id, "projectId": project_id, "location": location},
-        }
-
-        supported_jobs = {
-            LoadJob._JOB_TYPE: LoadJob,
-            CopyJob._JOB_TYPE: CopyJob,
-            ExtractJob._JOB_TYPE: ExtractJob,
-            QueryJob._JOB_TYPE: QueryJob,
-        }
-
-        job = None
-        for job_type, job_object in supported_jobs.items():
-            if job_type in configuration:
-                job = job_object
-                break
-
-        if not job:
-            raise AirflowException(f"Unknown job type. Supported types: {supported_jobs.keys()}")
-        job = job.from_api_repr(job_data, client)
-        self.log.info("Inserting job %s", job.job_id)
-        if nowait:
-            # Initiate the job and don't wait for it to complete.
-            job._begin()
-        else:
-            # Start the job and wait for it to complete and get the result.
-            job.result()
-        return job
-
-
 class BigQueryHookAsync(GoogleBaseHookAsync):
-    """Big query async hook inherits from GoogleBaseHookAsync class and connects to the google Big query"""
+    """Big query async hook inherits from GoogleBaseHookAsync class and connects to the Google Big Query"""
 
-    sync_hook_class = _BigQueryHook
+    sync_hook_class = BigQueryHook
+
+    def __init__(self, **kwargs: Any):
+        super().__init__(**kwargs)
 
     async def get_job_instance(
         self, project_id: Optional[str], job_id: Optional[str], session: ClientSession
@@ -132,8 +81,10 @@ class BigQueryHookAsync(GoogleBaseHookAsync):
         buffer = []
         if "rows" in query_results and query_results["rows"]:
             rows = query_results["rows"]
+            fields = query_results["schema"]["fields"]
+            col_types = [field["type"] for field in fields]
             for dict_row in rows:
-                typed_row = [vs["v"] for vs in dict_row["f"]]
+                typed_row = [bq_cast(vs["v"], col_types[idx]) for idx, vs in enumerate(dict_row["f"])]
                 buffer.append(typed_row)
         return buffer
 
