@@ -1,5 +1,4 @@
 import warnings
-from abc import ABC
 from typing import Any, Optional, Sequence, Tuple, Union
 
 from airflow.providers.google.common.consts import CLIENT_INFO
@@ -17,7 +16,7 @@ from google.cloud.dataproc_v1.types import clusters
 JobType = Union[Job, Any]
 
 
-class DataprocHookAsync(GoogleBaseHook, ABC):
+class DataprocHookAsync(GoogleBaseHook):
     """Async Hook for Google Cloud Dataproc APIs"""
 
     def get_cluster_client(
@@ -30,8 +29,16 @@ class DataprocHookAsync(GoogleBaseHook, ABC):
         :param location: (To be deprecated). The Cloud Dataproc region in which to handle the request.
         """
         client_options, region = self._get_client_options_and_region(region=region, location=location)
+        try:
+            # for apache-airflow-providers-google<8.4.0
+            credentials = self._get_credentials()  # type: ignore[attr-defined]
+        except AttributeError:  # pragma: no cover
+            # for apache-airflow-providers-google>=8.4.0
+            credentials = self.get_credentials()
         return ClusterControllerAsyncClient(
-            credentials=self._get_credentials(), client_info=CLIENT_INFO, client_options=client_options
+            credentials=credentials,
+            client_info=CLIENT_INFO,
+            client_options=client_options,
         )
 
     def get_job_client(
@@ -44,8 +51,16 @@ class DataprocHookAsync(GoogleBaseHook, ABC):
         :param location: (To be deprecated). The Cloud Dataproc region in which to handle the request.
         """
         client_options, region = self._get_client_options_and_region(region=region, location=location)
+        try:
+            # for apache-airflow-providers-google<8.4.0
+            credentials = self._get_credentials()  # type: ignore[attr-defined]
+        except AttributeError:  # pragma: no cover
+            # for apache-airflow-providers-google>=8.4.0
+            credentials = self.get_credentials()
         return JobControllerAsyncClient(
-            credentials=self._get_credentials(), client_info=CLIENT_INFO, client_options=client_options
+            credentials=credentials,
+            client_info=CLIENT_INFO,
+            client_options=client_options,
         )
 
     async def get_cluster(
