@@ -3,7 +3,7 @@ from typing import Any, Dict
 
 from airflow.exceptions import AirflowException
 from airflow.models.baseoperator import BaseOperator
-from airflow.providers.google.cloud.hooks.bigquery import BigQueryJob
+from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook, BigQueryJob
 from airflow.providers.google.cloud.operators.bigquery import (
     BigQueryCheckOperator,
     BigQueryGetDataOperator,
@@ -11,10 +11,8 @@ from airflow.providers.google.cloud.operators.bigquery import (
     BigQueryIntervalCheckOperator,
     BigQueryValueCheckOperator,
 )
-from airflow.utils.context import Context
 from google.api_core.exceptions import Conflict
 
-from astronomer.providers.google.cloud.hooks.bigquery import _BigQueryHook
 from astronomer.providers.google.cloud.triggers.bigquery import (
     BigQueryCheckTrigger,
     BigQueryGetDataTrigger,
@@ -22,6 +20,7 @@ from astronomer.providers.google.cloud.triggers.bigquery import (
     BigQueryIntervalCheckTrigger,
     BigQueryValueCheckTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 BIGQUERY_JOB_DETAILS_LINK_FMT = "https://console.cloud.google.com/bigquery?j={job_id}"
 
@@ -72,18 +71,12 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
     :param cancel_on_kill: Flag which indicates whether cancel the hook's job or not, when on_kill is called
     """
 
-    def _submit_job(self, hook: _BigQueryHook, job_id: str) -> BigQueryJob:  # type: ignore[override]
-        """Submit a new job and get the job id for polling the status using Triggerer."""
-        return hook.insert_job(
-            configuration=self.configuration,
-            project_id=self.project_id,
-            location=self.location,
-            job_id=job_id,
-            nowait=True,
-        )
-
     def execute(self, context: Context) -> None:  # noqa: D102
-        hook = _BigQueryHook(gcp_conn_id=self.gcp_conn_id)
+        hook = BigQueryHook(
+            gcp_conn_id=self.gcp_conn_id,
+            delegate_to=self.delegate_to,
+            impersonation_chain=self.impersonation_chain,
+        )
 
         self.hook = hook
         job_id = self.hook.generate_job_id(
@@ -125,6 +118,8 @@ class BigQueryInsertJobOperatorAsync(BigQueryInsertJobOperator, BaseOperator):
                 conn_id=self.gcp_conn_id,
                 job_id=self.job_id,
                 project_id=self.project_id,
+                delegate_to=self.delegate_to,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
@@ -152,7 +147,7 @@ class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
 
     def _submit_job(
         self,
-        hook: _BigQueryHook,
+        hook: BigQueryHook,
         job_id: str,
     ) -> BigQueryJob:
         """Submit a new job and get the job id for polling the status using Trigger."""
@@ -167,8 +162,9 @@ class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
         )
 
     def execute(self, context: Context) -> None:  # noqa: D102
-        hook = _BigQueryHook(
+        hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
+            impersonation_chain=self.impersonation_chain,
         )
         job = self._submit_job(hook, job_id="")
         context["ti"].xcom_push(key="job_id", value=job.job_id)
@@ -178,6 +174,7 @@ class BigQueryCheckOperatorAsync(BigQueryCheckOperator):
                 conn_id=self.gcp_conn_id,
                 job_id=job.job_id,
                 project_id=hook.project_id,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
@@ -248,9 +245,9 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    def _submit_job(
+    def _submit_job(  # type: ignore[override]
         self,
-        hook: _BigQueryHook,
+        hook: BigQueryHook,
         job_id: str,
         configuration: Dict[str, Any],
     ) -> BigQueryJob:
@@ -276,11 +273,11 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
         query += " from " + self.dataset_id + "." + self.table_id + " limit " + str(self.max_results)
         return query
 
-    def execute(self, context: Context) -> None:  # type: ignore[override]  # noqa: D102
+    def execute(self, context: Context) -> None:  # noqa: D102
         get_query = self.generate_query()
         configuration = {"query": {"query": get_query}}
 
-        hook = _BigQueryHook(
+        hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
             location=self.location,
@@ -299,6 +296,8 @@ class BigQueryGetDataOperatorAsync(BigQueryGetDataOperator):
                 dataset_id=self.dataset_id,
                 table_id=self.table_id,
                 project_id=hook.project_id,
+                delegate_to=self.delegate_to,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
@@ -349,7 +348,7 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
 
     def _submit_job(
         self,
-        hook: _BigQueryHook,
+        hook: BigQueryHook,
         sql: str,
         job_id: str,
     ) -> BigQueryJob:
@@ -363,9 +362,9 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
             nowait=True,
         )
 
-    def execute(self, context: Context) -> None:  # type: ignore[override]
+    def execute(self, context: Context) -> None:
         """Execute the job in sync mode and defers the trigger with job id to poll for the status"""
-        hook = _BigQueryHook(gcp_conn_id=self.gcp_conn_id)
+        hook = BigQueryHook(gcp_conn_id=self.gcp_conn_id)
         self.log.info("Using ratio formula: %s", self.ratio_formula)
 
         self.log.info("Executing SQL check: %s", self.sql1)
@@ -387,6 +386,7 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
                 days_back=self.days_back,
                 ratio_formula=self.ratio_formula,
                 ignore_zero=self.ignore_zero,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
@@ -410,7 +410,7 @@ class BigQueryIntervalCheckOperatorAsync(BigQueryIntervalCheckOperator):
 class BigQueryValueCheckOperatorAsync(BigQueryValueCheckOperator):  # noqa: D101
     def _submit_job(
         self,
-        hook: _BigQueryHook,
+        hook: BigQueryHook,
         job_id: str,
     ) -> BigQueryJob:
         """Submit a new job and get the job id for polling the status using Triggerer."""
@@ -431,8 +431,8 @@ class BigQueryValueCheckOperatorAsync(BigQueryValueCheckOperator):  # noqa: D101
             nowait=True,
         )
 
-    def execute(self, context: Context) -> None:  # type: ignore[override]  # noqa: D102
-        hook = _BigQueryHook(gcp_conn_id=self.gcp_conn_id)
+    def execute(self, context: Context) -> None:  # noqa: D102
+        hook = BigQueryHook(gcp_conn_id=self.gcp_conn_id)
 
         job = self._submit_job(hook, job_id="")
         context["ti"].xcom_push(key="job_id", value=job.job_id)
@@ -445,6 +445,7 @@ class BigQueryValueCheckOperatorAsync(BigQueryValueCheckOperator):  # noqa: D101
                 sql=self.sql,
                 pass_value=self.pass_value,
                 tolerance=self.tol,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
