@@ -14,7 +14,6 @@ from airflow.providers.google.cloud.operators.dataproc import (
     DataprocSubmitJobOperator,
     DataprocUpdateClusterOperator,
 )
-from airflow.utils.context import Context
 from google.api_core.exceptions import AlreadyExists
 
 from astronomer.providers.google.cloud.triggers.dataproc import (
@@ -22,6 +21,7 @@ from astronomer.providers.google.cloud.triggers.dataproc import (
     DataprocDeleteClusterTrigger,
     DataProcSubmitTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
 class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
@@ -74,7 +74,7 @@ class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
 
     def execute(self, context: Context) -> None:  # type: ignore[override]
         """Call create cluster API and defer to DataprocCreateClusterTrigger to check the status"""
-        hook = DataprocHook(gcp_conn_id=self.gcp_conn_id)
+        hook = DataprocHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         DataprocLink.persist(
             context=context, task_instance=self, url=DATAPROC_CLUSTER_LINK, resource=self.cluster_name
         )
@@ -95,7 +95,7 @@ class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
                 raise
             self.log.info("Cluster already exists.")
 
-        end_time: float = time.monotonic() + self.timeout
+        end_time: float = time.time() + self.timeout
 
         self.defer(
             trigger=DataprocCreateClusterTrigger(
@@ -108,12 +108,13 @@ class DataprocCreateClusterOperatorAsync(DataprocCreateClusterOperator):
                 cluster_config=self.cluster_config,
                 labels=self.labels,
                 gcp_conn_id=self.gcp_conn_id,
+                impersonation_chain=self.impersonation_chain,
                 polling_interval=self.polling_interval,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, Any]] = None) -> Any:
+    def execute_complete(self, context: Context, event: Optional[Dict[str, Any]] = None) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -167,7 +168,7 @@ class DataprocDeleteClusterOperatorAsync(DataprocDeleteClusterOperator):
         if self.timeout is None:
             self.timeout: float = 24 * 60 * 60
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         """Call delete cluster API and defer to wait for cluster to completely deleted"""
         hook = DataprocHook(gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain)
         self.log.info("Deleting cluster: %s", self.cluster_name)
@@ -181,10 +182,11 @@ class DataprocDeleteClusterOperatorAsync(DataprocDeleteClusterOperator):
             metadata=self.metadata,
         )
 
-        end_time: float = time.monotonic() + self.timeout
+        end_time: float = time.time() + self.timeout
 
         self.defer(
             trigger=DataprocDeleteClusterTrigger(
+                gcp_conn_id=self.gcp_conn_id,
                 project_id=self.project_id,
                 region=self.region,
                 cluster_name=self.cluster_name,
@@ -192,11 +194,12 @@ class DataprocDeleteClusterOperatorAsync(DataprocDeleteClusterOperator):
                 retry=self.retry,
                 end_time=end_time,
                 metadata=self.metadata,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, Any]] = None) -> Any:
+    def execute_complete(self, context: Context, event: Optional[Dict[str, Any]] = None) -> Any:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -239,7 +242,7 @@ class DataprocSubmitJobOperatorAsync(DataprocSubmitJobOperator):
     :param cancel_on_kill: Flag which indicates whether cancel the hook's job or not, when on_kill is called
     """
 
-    def execute(self, context: "Context") -> None:
+    def execute(self, context: Context) -> None:
         """
         Airflow runs this method on the worker and defers using the trigger.
         Submit the job and get the job_id using which we defer and poll in trigger
@@ -265,11 +268,14 @@ class DataprocSubmitJobOperatorAsync(DataprocSubmitJobOperator):
                 dataproc_job_id=job_id,
                 project_id=self.project_id,
                 region=self.region,
+                impersonation_chain=self.impersonation_chain,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, str]] = None) -> str:
+    def execute_complete(  # type: ignore[override]
+        self, context: Context, event: Optional[Dict[str, str]] = None
+    ) -> str:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
@@ -354,7 +360,7 @@ class DataprocUpdateClusterOperatorAsync(DataprocUpdateClusterOperator):
             metadata=self.metadata,
         )
 
-        end_time: float = time.monotonic() + self.timeout
+        end_time: float = time.time() + self.timeout
 
         self.defer(
             trigger=DataprocCreateClusterTrigger(
@@ -364,6 +370,7 @@ class DataprocUpdateClusterOperatorAsync(DataprocUpdateClusterOperator):
                 end_time=end_time,
                 metadata=self.metadata,
                 gcp_conn_id=self.gcp_conn_id,
+                impersonation_chain=self.impersonation_chain,
                 polling_interval=self.polling_interval,
             ),
             method_name="execute_complete",
