@@ -1,13 +1,15 @@
 """This module contains Google Big Query sensors."""
+import warnings
+from datetime import timedelta
 from typing import Any, Dict, Optional
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.sensors.bigquery import BigQueryTableExistenceSensor
-from airflow.utils.context import Context
 
 from astronomer.providers.google.cloud.triggers.bigquery import (
     BigQueryTableExistenceTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
 class BigQueryTableExistenceSensorAsync(BigQueryTableExistenceSensor):
@@ -44,18 +46,26 @@ class BigQueryTableExistenceSensorAsync(BigQueryTableExistenceSensor):
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
-        self.polling_interval = polling_interval
+        # TODO: Remove once deprecated
+        if polling_interval:
+            self.poke_interval = polling_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         self.gcp_conn_id = gcp_conn_id
 
     def execute(self, context: Context) -> None:
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=BigQueryTableExistenceTrigger(
                 dataset_id=self.dataset_id,
                 table_id=self.table_id,
                 project_id=self.project_id,
-                poll_interval=self.polling_interval,
+                poke_interval=self.poke_interval,
                 gcp_conn_id=self.gcp_conn_id,
                 hook_params={
                     "delegate_to": self.delegate_to,
@@ -65,7 +75,7 @@ class BigQueryTableExistenceSensorAsync(BigQueryTableExistenceSensor):
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[str, Any], event: Optional[Dict[str, str]] = None) -> str:
+    def execute_complete(self, context: Context, event: Optional[Dict[str, str]] = None) -> str:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
