@@ -1,15 +1,15 @@
 """This module contains Google Cloud Storage sensors."""
-
-from typing import Any, Dict, List, Optional, Sequence, Union
+import warnings
+from datetime import timedelta
+from typing import Any, Dict, List, Optional, Union
 
 from airflow.exceptions import AirflowException
-from airflow.models.baseoperator import BaseOperator
 from airflow.providers.google.cloud.sensors.gcs import (
+    GCSObjectExistenceSensor,
     GCSObjectsWithPrefixExistenceSensor,
     GCSObjectUpdateSensor,
     GCSUploadSessionCompleteSensor,
 )
-from airflow.utils.context import Context
 
 from astronomer.providers.google.cloud.triggers.gcs import (
     GCSBlobTrigger,
@@ -17,9 +17,10 @@ from astronomer.providers.google.cloud.triggers.gcs import (
     GCSPrefixBlobTrigger,
     GCSUploadSessionTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
-class GCSObjectExistenceSensorAsync(BaseOperator):
+class GCSObjectExistenceSensorAsync(GCSObjectExistenceSensor):
     """
     Checks for the existence of a file in Google Cloud Storage.
 
@@ -39,36 +40,30 @@ class GCSObjectExistenceSensorAsync(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
-    template_fields = ("bucket", "object", "impersonation_chain")
-    ui_color = "#f0eee4"
-
     def __init__(
         self,
-        *,
-        bucket: str,
-        object: str,  # noqa: A002
         polling_interval: float = 5.0,
-        google_cloud_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         **kwargs: Any,
     ) -> None:
+        # TODO: Remove once deprecated
+        if polling_interval:
+            self.poke_interval = polling_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(**kwargs)
-        self.bucket = bucket
-        self.object = object
-        self.polling_interval = polling_interval
-        self.google_cloud_conn_id = google_cloud_conn_id
-        self.delegate_to = delegate_to
-        self.impersonation_chain = impersonation_chain
 
     def execute(self, context: "Context") -> None:
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=GCSBlobTrigger(
                 bucket=self.bucket,
                 object_name=self.object,
-                polling_period_seconds=self.polling_interval,
+                poke_interval=self.poke_interval,
                 google_cloud_conn_id=self.google_cloud_conn_id,
                 hook_params={
                     "delegate_to": self.delegate_to,
@@ -120,17 +115,25 @@ class GCSObjectsWithPrefixExistenceSensorAsync(GCSObjectsWithPrefixExistenceSens
         polling_interval: float = 5.0,
         **kwargs: Any,
     ) -> None:
+        # TODO: Remove once deprecated
+        if polling_interval:
+            self.poke_interval = polling_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(**kwargs)
-        self.polling_interval = polling_interval
 
     def execute(self, context: Dict[str, Any]) -> None:  # type: ignore[override]
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=GCSPrefixBlobTrigger(
                 bucket=self.bucket,
                 prefix=self.prefix,
-                polling_period_seconds=self.polling_interval,
+                poke_interval=self.poke_interval,
                 google_cloud_conn_id=self.google_cloud_conn_id,
                 hook_params={
                     "delegate_to": self.delegate_to,
@@ -195,17 +198,25 @@ class GCSUploadSessionCompleteSensorAsync(GCSUploadSessionCompleteSensor):
         polling_interval: float = 5.0,
         **kwargs: Any,
     ) -> None:
+        # TODO: Remove once deprecated
+        if polling_interval:
+            self.poke_interval = polling_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(**kwargs)
-        self.polling_interval = polling_interval
 
     def execute(self, context: Context) -> None:
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=GCSUploadSessionTrigger(
                 bucket=self.bucket,
                 prefix=self.prefix,
-                polling_period_seconds=self.polling_interval,
+                poke_interval=self.poke_interval,
                 google_cloud_conn_id=self.google_cloud_conn_id,
                 inactivity_period=self.inactivity_period,
                 min_objects=self.min_objects,
@@ -262,18 +273,26 @@ class GCSObjectUpdateSensorAsync(GCSObjectUpdateSensor):
         polling_interval: float = 5,
         **kwargs: Any,
     ) -> None:
+        # TODO: Remove once deprecated
+        if polling_interval:
+            self.poke_interval = polling_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(**kwargs)
-        self.polling_interval = polling_interval
 
     def execute(self, context: Context) -> None:
         """Airflow runs this method on the worker and defers using the trigger."""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=GCSCheckBlobUpdateTimeTrigger(
                 bucket=self.bucket,
                 object_name=self.object,
                 ts=self.ts_func(context),
-                polling_period_seconds=self.polling_interval,
+                poke_interval=self.poke_interval,
                 google_cloud_conn_id=self.google_cloud_conn_id,
                 hook_params={
                     "delegate_to": self.delegate_to,
