@@ -1,14 +1,16 @@
+import warnings
+from datetime import timedelta
 from typing import Any, Dict
 
 from airflow import AirflowException
 from airflow.providers.microsoft.azure.sensors.data_factory import (
     AzureDataFactoryPipelineRunStatusSensor,
 )
-from airflow.utils.context import Context
 
 from astronomer.providers.microsoft.azure.triggers.data_factory import (
     ADFPipelineRunStatusSensorTrigger,
 )
+from astronomer.providers.utils.typing_compat import Context
 
 
 class AzureDataFactoryPipelineRunStatusSensorAsync(AzureDataFactoryPipelineRunStatusSensor):
@@ -28,24 +30,32 @@ class AzureDataFactoryPipelineRunStatusSensorAsync(AzureDataFactoryPipelineRunSt
         poll_interval: float = 5,
         **kwargs: Any,
     ):
-        self.poll_interval = poll_interval
+        # TODO: Remove once deprecated
+        if poll_interval:
+            self.poke_interval = poll_interval
+            warnings.warn(
+                "Argument `poll_interval` is deprecated and will be removed "
+                "in a future release.  Please use  `poke_interval` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(**kwargs)
 
     def execute(self, context: Context) -> None:
         """Defers trigger class to poll for state of the job run until it reaches a failure state or success state"""
         self.defer(
-            timeout=self.execution_timeout,
+            timeout=timedelta(seconds=self.timeout),
             trigger=ADFPipelineRunStatusSensorTrigger(
                 run_id=self.run_id,
                 azure_data_factory_conn_id=self.azure_data_factory_conn_id,
                 resource_group_name=self.resource_group_name,
                 factory_name=self.factory_name,
-                poll_interval=self.poll_interval,
+                poke_interval=self.poke_interval,
             ),
             method_name="execute_complete",
         )
 
-    def execute_complete(self, context: Dict[Any, Any], event: Dict[str, str]) -> None:
+    def execute_complete(self, context: Context, event: Dict[str, str]) -> None:
         """
         Callback for when the trigger fires - returns immediately.
         Relies on trigger to throw an exception, otherwise it assumes execution was
